| Title: | Pmetrics Reports App |
|---|---|
| Description: | Standalone golem-based Shiny app for reviewing Pmetrics run results and exporting PDF reports. |
| Authors: | Michael Neely [aut, cre] |
| Maintainer: | Michael Neely <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.3 |
| Built: | 2026-05-23 03:40:59 UTC |
| Source: | https://github.com/LAPKB/PmetricsReports |
Alias for [run_app()]
report_app(res = NULL, launch.browser = TRUE, ...)report_app(res = NULL, launch.browser = TRUE, ...)
res |
A PM_result object. |
launch.browser |
Passed to [shiny::runApp()]. |
... |
Additional options passed into golem options. |
Launch the Pmetrics Reports app
run_app(res = NULL, launch.browser = TRUE, background = launch.browser, ...)run_app(res = NULL, launch.browser = TRUE, background = launch.browser, ...)
res |
A PM_result object. |
launch.browser |
Passed to [shiny::runApp()]. |
background |
Launch the report in a background R process so multiple reports can stay open at once. Defaults to 'TRUE' when 'launch.browser = TRUE'. |
... |
Additional options passed into golem options. |